@@ -1,18 +1,20 @@
+import ctypes
 import tkinter as tk
 import tkinter.ttk as ttk
-from ctypes import windll, POINTER, Structure, c_bool, sizeof, windll, pointer, c_int
-from ctypes.wintypes import DWORD, HWND, ULONG
+from ctypes import windll, POINTER, Structure, c_bool, sizeof, windll, pointer, c_int, c_char, c_long, c_ulong
+from ctypes.wintypes import DWORD, HWND, ULONG, COLORREF
+
 from enum import Enum
 from typing import Literal
 
-from tkdev.devplyer import set_auto_install_plyer, install_plyer, DevNotification
+from tkdev.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevEmail
 from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, \
     Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
 from tkdev.devcore import DevAction, DevSysTray
 from tkdev.devdraw import DrawButton
 from tkdev.devpre import DevPreToolbox
-from tkdev.winico import (DevTray, WM_EVENT, download_winico,
+from tkdev.devtcl import (DevTray, WM_EVENT, download_winico,
                           WM_RBUTTONDOWN, WM_RBUTTONUP, WM_RBUTTONDBLCLK,
                           WM_LBUTTONDOWN, WM_LBUTTONUP, WM_LBUTTONDBLCLK,
                           WM_MBUTTONDOWN, WM_MBUTTONUP, WM_MBUTTONDBLCLK,
@@ -42,6 +44,8 @@ except ImportError:
     pass
 
 dwm = windll.dwmapi
+gdi = windll.gdi32
+user = windll.user32
 SetWindowCompositionAttribute = windll.user32.SetWindowCompositionAttribute
 SetWindowCompositionAttribute()
 windll.shcore.SetProcessDpiAwareness(1)
@@ -252,7 +256,7 @@ class WindowComPositionAttributeData(Structure):
     ]
 
 
-def dwm_set_window_attribute(window: tk.Tk, attribute, value):
+def DwmSetWindowAttribute(window: tk.Tk, attribute, value):
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), attribute, value)
 
 
@@ -1571,6 +1575,4 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    Window = DevWindow()
-    DevNotification().show()
-    Window.mainloop()
+    Install("urllib")
\ No newline at end of file
